#[message_handler]Expand description
This attribute is used to mark the methods that are going to handle the messages that the actor can receive.
#[message_handler]This attribute is used to mark the methods that are going to handle the messages that the actor can receive.